"""
Blessed Linkedin-Ads connector for Airbyte SDK.

Auto-generated from OpenAPI specification.
"""

from .connector import LinkedinAdsConnector
from .models import (
    LinkedinAdsAuthConfig,
    LinkedinAdsReplicationConfig,
    AccountVersion,
    AccountChangeauditstampsLastmodified,
    AccountChangeauditstampsCreated,
    AccountChangeauditstamps,
    Account,
    AccountsListMetadata,
    AccountsList,
    AccountUserChangeauditstampsCreated,
    AccountUserChangeauditstampsLastmodified,
    AccountUserChangeauditstamps,
    AccountUser,
    AccountUsersListMetadata,
    AccountUsersList,
    CampaignVersion,
    CampaignUnitcost,
    CampaignLocale,
    CampaignChangeauditstampsLastmodified,
    CampaignChangeauditstampsCreated,
    CampaignChangeauditstamps,
    CampaignDailybudget,
    CampaignTotalbudget,
    CampaignRunschedule,
    Campaign,
    CampaignsListMetadata,
    CampaignsList,
    CampaignGroupChangeauditstampsLastmodified,
    CampaignGroupChangeauditstampsCreated,
    CampaignGroupChangeauditstamps,
    CampaignGroupTotalbudget,
    CampaignGroupRunschedule,
    CampaignGroup,
    CampaignGroupsListMetadata,
    CampaignGroupsList,
    CreativeLeadgencalltoaction,
    CreativeReview,
    Creative,
    CreativesListMetadata,
    CreativesList,
    ConversionValue,
    Conversion,
    ConversionsListPaging,
    ConversionsList,
    AdAnalyticsRecordDaterangeStart,
    AdAnalyticsRecordDaterangeEnd,
    AdAnalyticsRecordDaterange,
    AdAnalyticsRecord,
    AdAnalyticsResponsePaging,
    AdAnalyticsResponse,
    AccountsListResultMeta,
    AccountUsersListResultMeta,
    CampaignsListResultMeta,
    CampaignGroupsListResultMeta,
    CreativesListResultMeta,
    ConversionsListResultMeta,
    LinkedinAdsCheckResult,
    LinkedinAdsExecuteResult,
    LinkedinAdsExecuteResultWithMeta,
    AccountsListResult,
    AccountUsersListResult,
    CampaignsListResult,
    CampaignGroupsListResult,
    CreativesListResult,
    ConversionsListResult,
    AdCampaignAnalyticsListResult,
    AdCreativeAnalyticsListResult,
    AirbyteSearchMeta,
    AirbyteSearchResult,
    AccountsSearchData,
    AccountsSearchResult,
    AccountUsersSearchData,
    AccountUsersSearchResult,
    CampaignsSearchData,
    CampaignsSearchResult,
    CampaignGroupsSearchData,
    CampaignGroupsSearchResult,
    CreativesSearchData,
    CreativesSearchResult,
    ConversionsSearchData,
    ConversionsSearchResult,
    AdCampaignAnalyticsSearchData,
    AdCampaignAnalyticsSearchResult,
    AdCreativeAnalyticsSearchData,
    AdCreativeAnalyticsSearchResult
)
from .types import (
    AccountsListParams,
    AccountsGetParams,
    AccountUsersListParams,
    CampaignsListParams,
    CampaignsGetParams,
    CampaignGroupsListParams,
    CampaignGroupsGetParams,
    CreativesListParams,
    CreativesGetParams,
    ConversionsListParams,
    ConversionsGetParams,
    AdCampaignAnalyticsListParams,
    AdCreativeAnalyticsListParams,
    AirbyteSearchParams,
    AirbyteSortOrder,
    AccountsSearchFilter,
    AccountsSearchQuery,
    AccountsCondition,
    AccountUsersSearchFilter,
    AccountUsersSearchQuery,
    AccountUsersCondition,
    CampaignsSearchFilter,
    CampaignsSearchQuery,
    CampaignsCondition,
    CampaignGroupsSearchFilter,
    CampaignGroupsSearchQuery,
    CampaignGroupsCondition,
    CreativesSearchFilter,
    CreativesSearchQuery,
    CreativesCondition,
    ConversionsSearchFilter,
    ConversionsSearchQuery,
    ConversionsCondition,
    AdCampaignAnalyticsSearchFilter,
    AdCampaignAnalyticsSearchQuery,
    AdCampaignAnalyticsCondition,
    AdCreativeAnalyticsSearchFilter,
    AdCreativeAnalyticsSearchQuery,
    AdCreativeAnalyticsCondition
)
from ._vendored.connector_sdk.types import AirbyteHostedAuthConfig as AirbyteAuthConfig

__all__ = [
    "LinkedinAdsConnector",
    "AirbyteAuthConfig",
    "LinkedinAdsAuthConfig",
    "LinkedinAdsReplicationConfig",
    "AccountVersion",
    "AccountChangeauditstampsLastmodified",
    "AccountChangeauditstampsCreated",
    "AccountChangeauditstamps",
    "Account",
    "AccountsListMetadata",
    "AccountsList",
    "AccountUserChangeauditstampsCreated",
    "AccountUserChangeauditstampsLastmodified",
    "AccountUserChangeauditstamps",
    "AccountUser",
    "AccountUsersListMetadata",
    "AccountUsersList",
    "CampaignVersion",
    "CampaignUnitcost",
    "CampaignLocale",
    "CampaignChangeauditstampsLastmodified",
    "CampaignChangeauditstampsCreated",
    "CampaignChangeauditstamps",
    "CampaignDailybudget",
    "CampaignTotalbudget",
    "CampaignRunschedule",
    "Campaign",
    "CampaignsListMetadata",
    "CampaignsList",
    "CampaignGroupChangeauditstampsLastmodified",
    "CampaignGroupChangeauditstampsCreated",
    "CampaignGroupChangeauditstamps",
    "CampaignGroupTotalbudget",
    "CampaignGroupRunschedule",
    "CampaignGroup",
    "CampaignGroupsListMetadata",
    "CampaignGroupsList",
    "CreativeLeadgencalltoaction",
    "CreativeReview",
    "Creative",
    "CreativesListMetadata",
    "CreativesList",
    "ConversionValue",
    "Conversion",
    "ConversionsListPaging",
    "ConversionsList",
    "AdAnalyticsRecordDaterangeStart",
    "AdAnalyticsRecordDaterangeEnd",
    "AdAnalyticsRecordDaterange",
    "AdAnalyticsRecord",
    "AdAnalyticsResponsePaging",
    "AdAnalyticsResponse",
    "AccountsListResultMeta",
    "AccountUsersListResultMeta",
    "CampaignsListResultMeta",
    "CampaignGroupsListResultMeta",
    "CreativesListResultMeta",
    "ConversionsListResultMeta",
    "LinkedinAdsCheckResult",
    "LinkedinAdsExecuteResult",
    "LinkedinAdsExecuteResultWithMeta",
    "AccountsListResult",
    "AccountUsersListResult",
    "CampaignsListResult",
    "CampaignGroupsListResult",
    "CreativesListResult",
    "ConversionsListResult",
    "AdCampaignAnalyticsListResult",
    "AdCreativeAnalyticsListResult",
    "AirbyteSearchMeta",
    "AirbyteSearchResult",
    "AccountsSearchData",
    "AccountsSearchResult",
    "AccountUsersSearchData",
    "AccountUsersSearchResult",
    "CampaignsSearchData",
    "CampaignsSearchResult",
    "CampaignGroupsSearchData",
    "CampaignGroupsSearchResult",
    "CreativesSearchData",
    "CreativesSearchResult",
    "ConversionsSearchData",
    "ConversionsSearchResult",
    "AdCampaignAnalyticsSearchData",
    "AdCampaignAnalyticsSearchResult",
    "AdCreativeAnalyticsSearchData",
    "AdCreativeAnalyticsSearchResult",
    "AccountsListParams",
    "AccountsGetParams",
    "AccountUsersListParams",
    "CampaignsListParams",
    "CampaignsGetParams",
    "CampaignGroupsListParams",
    "CampaignGroupsGetParams",
    "CreativesListParams",
    "CreativesGetParams",
    "ConversionsListParams",
    "ConversionsGetParams",
    "AdCampaignAnalyticsListParams",
    "AdCreativeAnalyticsListParams",
    "AirbyteSearchParams",
    "AirbyteSortOrder",
    "AccountsSearchFilter",
    "AccountsSearchQuery",
    "AccountsCondition",
    "AccountUsersSearchFilter",
    "AccountUsersSearchQuery",
    "AccountUsersCondition",
    "CampaignsSearchFilter",
    "CampaignsSearchQuery",
    "CampaignsCondition",
    "CampaignGroupsSearchFilter",
    "CampaignGroupsSearchQuery",
    "CampaignGroupsCondition",
    "CreativesSearchFilter",
    "CreativesSearchQuery",
    "CreativesCondition",
    "ConversionsSearchFilter",
    "ConversionsSearchQuery",
    "ConversionsCondition",
    "AdCampaignAnalyticsSearchFilter",
    "AdCampaignAnalyticsSearchQuery",
    "AdCampaignAnalyticsCondition",
    "AdCreativeAnalyticsSearchFilter",
    "AdCreativeAnalyticsSearchQuery",
    "AdCreativeAnalyticsCondition",
]